@@ -6,6 +6,7 @@
  *                                         *
  *******************************************/
 #include "weighted_left_product.h"
+#include <RcppParallel.h>
 
 using namespace Rcpp;
 using namespace RcppParallel;
@@ -37,7 +38,7 @@ struct paraWLP : public Worker {
 // std::cout << "i = " << i << "\n";
       gg[1] = we[i];
       gg[2] = 2*we[i];
-      gg[3] = 2*p[i]; // imputation par le "génotype moyen"
+      gg[3] = 2*p[i]*we[i]; // imputation par le "génotype moyen"
       for(size_t c = 0; c < r; c++) {
         size_t k = c*ncol;
         for(size_t j = 0; j < true_ncol; j++) {
@@ -58,22 +59,22 @@ NumericMatrix WLP(XPtr<matrix4> pA, NumericVector p, const std::vector<double> &
   return WLP(const_cast<const uint8_t **>(pA->data), const_cast<const double *>(&p[0]), pA->nrow, pA->ncol, pA->true_ncol, we, v);
 }
 
-// calcule R = v' GW avec G = génotype 0 1 2 (donné par pA), W = matrice diagonale des poids (donnés par we)
-// le résultat a dimensions nb_snps x v.ncol() ...
+// calcule R = v' GW ///!!!! PLUS EXACTEMENT SA TRANSPOSEE WG'v !!!!!!!!
+// avec G = (n x m) génotype 0 1 2 (donné par pA), W = matrice diagonale des poids (donnés par we)
+// le résultat a dimensions   nb_snps (m) x v.ncol() (r)...
 NumericMatrix WLP(const uint8_t ** A_data, const double * p, size_t A_nrow, size_t A_ncol, size_t A_true_ncol, 
                   const std::vector<double> & we, NumericMatrix & v) {
-  int n = A_nrow; // nb snps
-  int m = A_ncol; // nb inds
-  // Rcout << "m = " << m << " v.nrow = " << v.nrow() << "\n";
-  // Rcout << "n = " << n << " we.size = " << we.size() << "\n";
-  if(m != v.nrow() || n != we.size()) stop("Dimensions mismatch");
+  int n = A_ncol; // nb inds
+  int m = A_nrow; // nb snps
+  // Rcout << "n = " << n << " v.nrow = " << v.nrow() << "\n";
+  // Rcout << "m = " << m << " we.size = " << we.size() << "\n";
+  if(n != v.nrow() || m != we.size()) stop("Dimensions mismatch (WLP)");
   int r = v.ncol();
 
-  NumericMatrix R(n,r);
+  NumericMatrix R(m,r);
   paraWLP X(A_data, p, A_nrow, A_ncol, A_true_ncol, we, r, v.begin(), R.begin());
 
-  parallelFor(0, n, X);
+  parallelFor(0, m, X);
   return R;
 }
 
-
